==> fox-1.4.1.tar.gz: fox/README.md <==
# Fox module

The module adds drush command: fox:console (fox). Command allow you to obtain data at entity (context) levels. Context: entity_type.bundle .The module can be useful during migrations or in cases where there is only console access.

Console is a looped interactive command (like FoxPro command window). The module keeps command history (by arrows up/down) and autocomplete (by tab).

Fox commands:

  - USE
    Select context, for example node.page (node entity type, page bundle).
    Usage: USE [context]. USE without context cleared existing context.
  - GO
    Set context record.
    Usage: GO {TOP|BOTTOM|PREV [number]|NEXT [number]|number}
  - SEEK
    Seek context record by entity ID.
    Usage: SEEK id
  - BROWSE
    Browse fields for context record.
    Usage: BROWSE [*|fields] --vertical, --json").

  - APPEND
    Append record with fields.
    Usage: APPEND [uField1 WITH eExpr1 [, uField2 WITH eExpr2]
  - CLONE
    Clone context record.
    Usage: CLONE
  - REPLACE
    Replace fields for context record.
    Usage: REPLACE uField1 WITH eExpr1 [, uField2 WITH eExpr2]
  - DELETE
    Delete context record.
    Usage: DELETE

  - SET
    Set variables.
    Usage: SET var1 TO eExpr1 [, var2 TO eExpr2].
    Delete variable: SET var1 TO
  - PRINT
    Print variable.
    Usage:PRINT @var

  - LOAD
    Load file with fox commands.
    Usage: LOAD file
  - DRUSH
    Call an external Drush command.
    Usage: DRUSH command [JSON args] [JSON options])

  - INFO
    List entities,bundles or fields list for entity,bundle.
    Usage: INFO [entity_id.[bundle]]
  - LIST
    List Fox commands.
    Usage: LIST

## Table of contents

- Requirements
- Installation
- Configuration
- Maintainers

## Requirements

  - Install drush/drush
  - Install greenlion/php-sql-parser

## Installation

Install as you would normally install a contributed Drupal module. For further information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

  Drush command:
    fox:console (fox) --mode=[default]|debug --input="commands split ; or filename" --output[= filename]
    Run fox commands and query.

## Maintainers

- Serhii Klietsov - [goodboy](https://drupal.org/user/222910)

==> fox-1.4.2.tar.gz: fox/README.md <==
# Fox module

The module adds drush command: fox:console (fox). Command allow you to
obtain data at entity (context) levels. Context: entity_type.bundle.
The module can be useful during migrations or in cases where there
is only console access.

Console is a looped interactive command (like FoxPro command window).
The module keeps command history (by arrows up/down) and
autocomplete (by tab).

Fox commands:

  - USE
    Select context, for example node.page (node entity type, page bundle).
    Usage: USE [context]. USE without context cleared existing context.
  - GO
    Set context record.
    Usage: GO {TOP|BOTTOM|PREV [number]|NEXT [number]|number}
  - SEEK
    Seek context record by entity ID.
    Usage: SEEK id
  - BROWSE
    Browse fields for context record.
    Usage: BROWSE [*|fields] --vertical, --json").

  - APPEND
    Append record with fields.
    Usage: APPEND [uField1 WITH eExpr1 [, uField2 WITH eExpr2]
  - CLONE
    Clone context record.
    Usage: CLONE
  - REPLACE
    Replace fields for context record.
    Usage: REPLACE uField1 WITH eExpr1 [, uField2 WITH eExpr2] [LOOP @variable]
  - DELETE
    Delete context record.
    Usage: DELETE [LOOP @variable]

  - SET
    Set variables.
    Usage: SET var1 TO eExpr1 [, var2 TO eExpr2].
    Delete variable: SET var1 TO
  - PRINT
    Print variable.
    Usage:PRINT @var

  - LOAD
    Load file with fox commands.
    Usage: LOAD file
  - DRUSH
    Call an external Drush command.
    Usage: DRUSH command [JSON args] [JSON options])

  - INFO
    List entities,bundles or fields list for entity,bundle.
    Usage: INFO [entity_id.[bundle]]
  - LIST
    List Fox commands.
    Usage: LIST
  - SQL
    Execute SELECT SQL
    Usage: SQL expressions [INTO variable]

## Table of contents

- Requirements
- Installation
- Configuration
- Maintainers

## Requirements

  - Install drush/drush
  - Install greenlion/php-sql-parser

## Installation

Install as you would normally install a contributed Drupal module. For further information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

  Drush command:
    fox:console (fox)
      --mode=[default]|debug
      --input="commands split ; or filename"
      --output[= filename]
    Run fox commands and query.

## Maintainers

- Serhii Klietsov - [goodboy](https://drupal.org/user/222910)
